import { RefObject, useEffect } from 'react';

export type Handler = () => void;

export function useOnClickOutside<T extends HTMLElement = HTMLElement>(
    ref: RefObject<T>,
    handler: Handler,
    mouseEvent: 'click' | 'mousedown' | 'mouseup' = 'click'
): void {
    const handleEventListener = (event: MouseEvent) => {
        const el = ref?.current;
        if (!el || el.contains(event.target as Node)) {
            return;
        }
        handler();
    };
    useEffect(() => {
        if (document) {
            document.addEventListener(mouseEvent, handleEventListener);
            return () => {
                document.removeEventListener(mouseEvent, handleEventListener);
            };
        }
    }, []);
}
